import family.*;

import java.io.*;
import java.util.*;
import javax.servlet.UnavailableException;
import javax.servlet.ServletException;
import javax.servlet.http.*;


public class Finder extends HttpServlet {

	private volatile String jdbcURI; // final after init
	private volatile String charset; // final after init

	@Override public void init() throws UnavailableException {
		charset = getInitParameter("charset");
		if( charset == null )
			throw new UnavailableException("Application is not configured properly: charset is not set.");
		jdbcURI = getInitParameter("jdbcURI");
		if( jdbcURI == null )
			throw new UnavailableException("Application is not configured properly: jdbcURI is not set.");
		try {
			Class.forName( getInitParameter("jdbcDriver") );
		} catch( Exception e ){
			throw new UnavailableException("Application is not configured properly: jdbcDriver cannot be loaded.");
		}
	}

	@Override public void doGet( HttpServletRequest req, HttpServletResponse res ) throws ServletException, IOException {
		String name = req.getParameter("name");
		if( name == null ){
			res.sendError(HttpServletResponse.SC_BAD_REQUEST,"Provide a name to query.");
		} else {
			try {
				Set<Person> persons = new Dao(jdbcURI).findByName(name);
				res.setContentType("text/html;charset="+charset);
				PrintWriter out = res.getWriter();
				printResponse(out,persons);
			} catch( Dao.Exception e ){
				e.printStackTrace();
				res.sendError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR,e.getMessage());
			}
		}
	}

	private void printResponse( PrintWriter out, Set<Person> persons ){
		out.print("<HTML><HEAD><META HTTP-EQUIV=\"Content-Type\" CONTENT=\"text/html;charset=");
		out.print(charset);
		out.println("\"><TITLE>Persons</TITLE></HEAD><BODY>");
		out.println(persons);
		out.println("</BODY></HTML>");
	}

}
